/* unattended-setup-box.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from unattended-setup-box.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _BoxesUnattendedSetupBoxPrivate BoxesUnattendedSetupBoxPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

struct _BoxesUnattendedSetupBox {
	GtkBox parent_instance;
	BoxesUnattendedSetupBoxPrivate * priv;
};

struct _BoxesUnattendedSetupBoxClass {
	GtkBoxClass parent_class;
};

struct _BoxesUnattendedSetupBoxPrivate {
	GtkInfoBar* needs_internet_bar;
	GtkLabel* needs_internet_label;
	GtkGrid* setup_grid;
	GtkLabel* express_label;
	GtkSwitch* express_toggle;
	GtkImage* user_avatar;
	GtkEntry* username_entry;
	GtkNotebook* password_notebook;
	GtkEntry* password_entry;
	GtkLabel* product_key_label;
	GtkEntry* product_key_entry;
	gchar* product_key_format;
	gchar* media_path;
	GKeyFile* keyfile;
	gboolean we_inserted_text;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};


static gpointer boxes_unattended_setup_box_parent_class = NULL;

GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_SETUP_BOX_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxPrivate))
enum  {
	BOXES_UNATTENDED_SETUP_BOX_DUMMY_PROPERTY,
	BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS,
	BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE,
	BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL,
	BOXES_UNATTENDED_SETUP_BOX_USERNAME,
	BOXES_UNATTENDED_SETUP_BOX_PASSWORD,
	BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD,
	BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY,
	BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH
};
#define BOXES_UNATTENDED_SETUP_BOX_KEY_FILE "setup-data.conf"
#define BOXES_UNATTENDED_SETUP_BOX_EXPRESS_KEY "express-install"
#define BOXES_UNATTENDED_SETUP_BOX_USERNAME_KEY "username"
#define BOXES_UNATTENDED_SETUP_BOX_PASSWORD_KEY "password"
#define BOXES_UNATTENDED_SETUP_BOX_PRODUCTKEY_KEY "product-key"
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesUnattendedSetupBox* boxes_unattended_setup_box_new (BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet);
BoxesUnattendedSetupBox* boxes_unattended_setup_box_construct (GType object_type, BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
static void boxes_unattended_setup_box_set_entry_text_from_key (BoxesUnattendedSetupBox* self, GtkEntry* entry, const gchar* key, const gchar* default_value);
gchar* boxes_unattended_setup_box_get_password (BoxesUnattendedSetupBox* self);
static void boxes_unattended_setup_box_setup_express_toggle (BoxesUnattendedSetupBox* self, gboolean live, gboolean needs_internet);
void boxes_unattended_setup_box_clean_up (BoxesUnattendedSetupBox* self);
static void boxes_unattended_setup_box_update_express_toggle (BoxesUnattendedSetupBox* self, gboolean network_available);
static void _boxes_unattended_setup_box_update_express_toggle_g_network_monitor_network_changed (GNetworkMonitor* _sender, gboolean available, gpointer self);
void boxes_unattended_setup_box_save_settings (BoxesUnattendedSetupBox* self);
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self);
gchar* boxes_unattended_setup_box_get_product_key (BoxesUnattendedSetupBox* self);
static void boxes_unattended_setup_box_on_mandatory_input_changed (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_unattended_setup_box_on_username_entry_activated (BoxesUnattendedSetupBox* self);
gboolean boxes_unattended_setup_box_get_ready_for_express (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_password_button_clicked (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean boxes_unattended_setup_box_on_password_entry_focus_out (BoxesUnattendedSetupBox* self);
static gboolean _boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void boxes_unattended_setup_box_on_password_entry_activated (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_key_entry_activated (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_key_text_inserted (BoxesUnattendedSetupBox* self, const gchar* text, gint text_length, gint* position);
static void _boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
gboolean boxes_unattended_setup_box_get_ready_to_create (BoxesUnattendedSetupBox* self);
void boxes_unattended_setup_box_set_express_install (BoxesUnattendedSetupBox* self, gboolean value);
gchar* boxes_unattended_setup_box_get_hidden_password (BoxesUnattendedSetupBox* self);
void boxes_unattended_setup_box_set_avatar_path (BoxesUnattendedSetupBox* self, const gchar* value);
static void boxes_unattended_setup_box_finalize (GObject* obj);
static void _vala_boxes_unattended_setup_box_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_unattended_setup_box_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


BoxesUnattendedSetupBox* boxes_unattended_setup_box_construct (GType object_type, BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet) {
	BoxesUnattendedSetupBox * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* msg = NULL;
	const gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkInfoBar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	BoxesInstallerMedia* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GKeyFile* _tmp12_ = NULL;
	BoxesInstallerMedia* _tmp27_ = NULL;
	OsinfoMedia* _tmp28_ = NULL;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp30_ = FALSE;
	gboolean _tmp31_ = FALSE;
	const gchar* _tmp32_ = NULL;
	GtkGrid* _tmp43_ = NULL;
	GList* _tmp44_ = NULL;
	GError * _inner_error_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self = (BoxesUnattendedSetupBox*) g_object_new (object_type, NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = product_key_format;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->product_key_format);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv->product_key_format = _tmp1_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _ ("Express installation of %s requires an internet connection.");
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = media;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp4_ = _tmp3_->label;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp5_ = g_strdup_printf (_tmp2_, _tmp4_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	msg = _tmp5_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp6_ = self->priv->needs_internet_label;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_label_set_label (_tmp6_, msg);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp7_ = self->priv->needs_internet_bar;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp8_ = needs_internet;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp7_, _tmp8_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp9_ = media;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp10_ = _tmp9_->device_file;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->media_path);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv->media_path = _tmp11_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp12_ = g_key_file_new ();
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_key_file_unref0 (self->priv->keyfile);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv->keyfile = _tmp12_;
#line 258 "unattended-setup-box.c"
	{
		gchar* filename = NULL;
		gchar* _tmp13_ = NULL;
		GKeyFile* _tmp14_ = NULL;
		GtkEntry* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		GtkEntry* _tmp17_ = NULL;
		GtkEntry* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gboolean _tmp22_ = FALSE;
		GtkEntry* _tmp24_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp13_ = boxes_get_user_unattended (BOXES_UNATTENDED_SETUP_BOX_KEY_FILE);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		filename = _tmp13_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp14_ = self->priv->keyfile;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_key_file_load_from_file (_tmp14_, filename, G_KEY_FILE_KEEP_COMMENTS, &_inner_error_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_g_free0 (filename);
#line 284 "unattended-setup-box.c"
			goto __catch89_g_error;
		}
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp15_ = self->priv->username_entry;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp16_ = g_get_user_name ();
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_entry_text_from_key (self, _tmp15_, BOXES_UNATTENDED_SETUP_BOX_USERNAME_KEY, _tmp16_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp17_ = self->priv->password_entry;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_entry_text_from_key (self, _tmp17_, BOXES_UNATTENDED_SETUP_BOX_PASSWORD_KEY, NULL);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp18_ = self->priv->password_entry;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_entry_text_from_key (self, _tmp18_, BOXES_UNATTENDED_SETUP_BOX_PASSWORD_KEY, NULL);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp19_ = boxes_unattended_setup_box_get_password (self);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp20_ = _tmp19_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp21_ = _tmp20_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp22_ = g_strcmp0 (_tmp21_, "") != 0;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (_tmp21_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp22_) {
#line 313 "unattended-setup-box.c"
			GtkNotebook* _tmp23_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp23_ = self->priv->password_notebook;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_notebook_next_page (_tmp23_);
#line 319 "unattended-setup-box.c"
		}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp24_ = self->priv->product_key_entry;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_entry_text_from_key (self, _tmp24_, BOXES_UNATTENDED_SETUP_BOX_PRODUCTKEY_KEY, NULL);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (filename);
#line 327 "unattended-setup-box.c"
	}
	goto __finally89;
	__catch89_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp25_ = _error_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp26_ = _tmp25_->message;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:122: %s either doesn't already exist or we f" \
"ailed to load it: %s", BOXES_UNATTENDED_SETUP_BOX_KEY_FILE, _tmp26_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 347 "unattended-setup-box.c"
	}
	__finally89:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (msg);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return NULL;
#line 360 "unattended-setup-box.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp27_ = media;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp28_ = _tmp27_->os_media;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_get (_tmp28_, "live", &_tmp29_, NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp30_ = _tmp29_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp31_ = needs_internet;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_setup_express_toggle (self, _tmp30_, _tmp31_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp32_ = product_key_format;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp32_ != NULL) {
#line 378 "unattended-setup-box.c"
		GtkLabel* _tmp33_ = NULL;
		GtkEntry* _tmp34_ = NULL;
		GtkEntry* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		GtkEntry* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		gint _tmp41_ = 0;
		gint _tmp42_ = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp33_ = self->priv->product_key_label;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp33_, TRUE);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp34_ = self->priv->product_key_entry;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp34_, TRUE);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp35_ = self->priv->product_key_entry;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp36_ = product_key_format;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp37_ = strlen (_tmp36_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp38_ = _tmp37_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_entry_set_width_chars (_tmp35_, _tmp38_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp39_ = self->priv->product_key_entry;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp40_ = product_key_format;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp41_ = strlen (_tmp40_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp42_ = _tmp41_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_entry_set_max_length (_tmp39_, _tmp42_);
#line 417 "unattended-setup-box.c"
	}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp43_ = self->priv->setup_grid;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp44_ = gtk_container_get_children ((GtkContainer*) _tmp43_);
#line 423 "unattended-setup-box.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		child_collection = _tmp44_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 431 "unattended-setup-box.c"
			GtkWidget* child = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			child = (GtkWidget*) child_it->data;
#line 435 "unattended-setup-box.c"
			{
				gboolean _tmp45_ = FALSE;
				GtkWidget* _tmp46_ = NULL;
				GtkLabel* _tmp47_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp46_ = child;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp47_ = self->priv->express_label;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp46_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_widget_get_type (), GtkWidget)) {
#line 446 "unattended-setup-box.c"
					GtkWidget* _tmp48_ = NULL;
					GtkSwitch* _tmp49_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp48_ = child;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp49_ = self->priv->express_toggle;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp45_ = _tmp48_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_widget_get_type (), GtkWidget);
#line 455 "unattended-setup-box.c"
				} else {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp45_ = FALSE;
#line 459 "unattended-setup-box.c"
				}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp45_) {
#line 463 "unattended-setup-box.c"
					GtkSwitch* _tmp50_ = NULL;
					GtkWidget* _tmp51_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp50_ = self->priv->express_toggle;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp51_ = child;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					g_object_bind_property_with_closures ((GObject*) _tmp50_, "active", (GObject*) _tmp51_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 472 "unattended-setup-box.c"
				}
			}
		}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_list_free0 (child_collection);
#line 478 "unattended-setup-box.c"
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (msg);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return self;
#line 484 "unattended-setup-box.c"
}


BoxesUnattendedSetupBox* boxes_unattended_setup_box_new (BoxesInstallerMedia* media, const gchar* product_key_format, gboolean needs_internet) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return boxes_unattended_setup_box_construct (BOXES_TYPE_UNATTENDED_SETUP_BOX, media, product_key_format, needs_internet);
#line 491 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_update_express_toggle_g_network_monitor_network_changed (GNetworkMonitor* _sender, gboolean available, gpointer self) {
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_update_express_toggle ((BoxesUnattendedSetupBox*) self, available);
#line 498 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_clean_up (BoxesUnattendedSetupBox* self) {
	GNetworkMonitor* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = g_network_monitor_get_default ();
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_parse_name ("network-changed", g_network_monitor_get_type (), &_tmp1_, NULL, FALSE);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _boxes_unattended_setup_box_update_express_toggle_g_network_monitor_network_changed, self);
#line 513 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_save_settings (BoxesUnattendedSetupBox* self) {
	GKeyFile* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GKeyFile* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GKeyFile* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	GKeyFile* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* filename = NULL;
	gchar* _tmp18_ = NULL;
	GError * _inner_error_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->keyfile;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->media_path;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = boxes_unattended_setup_box_get_express_install (self);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = _tmp2_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_key_file_set_boolean (_tmp0_, _tmp1_, BOXES_UNATTENDED_SETUP_BOX_EXPRESS_KEY, _tmp3_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp4_ = self->priv->keyfile;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp5_ = self->priv->media_path;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp6_ = boxes_unattended_setup_box_get_username (self);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp7_ = _tmp6_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_key_file_set_string (_tmp4_, _tmp5_, BOXES_UNATTENDED_SETUP_BOX_USERNAME_KEY, _tmp7_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp8_ = self->priv->keyfile;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp9_ = self->priv->media_path;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp10_ = boxes_unattended_setup_box_get_password (self);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp11_ = _tmp10_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp12_ = _tmp11_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_key_file_set_string (_tmp8_, _tmp9_, BOXES_UNATTENDED_SETUP_BOX_PASSWORD_KEY, _tmp12_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (_tmp12_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp13_ = self->priv->keyfile;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp14_ = self->priv->media_path;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp15_ = boxes_unattended_setup_box_get_product_key (self);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp16_ = _tmp15_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp17_ = _tmp16_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_key_file_set_string (_tmp13_, _tmp14_, BOXES_UNATTENDED_SETUP_BOX_PRODUCTKEY_KEY, _tmp17_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (_tmp17_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp18_ = boxes_get_user_unattended (BOXES_UNATTENDED_SETUP_BOX_KEY_FILE);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	filename = _tmp18_;
#line 593 "unattended-setup-box.c"
	{
		GKeyFile* _tmp19_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp19_ = self->priv->keyfile;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_key_file_save_to_file (_tmp19_, filename, &_inner_error_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 602 "unattended-setup-box.c"
			goto __catch90_g_error;
		}
	}
	goto __finally90;
	__catch90_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp20_ = NULL;
		GError* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp20_ = self->priv->media_path;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp21_ = _error_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp22_ = _tmp21_->message;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:153: Error saving settings for '%s': %s", _tmp20_, _tmp22_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 627 "unattended-setup-box.c"
	}
	__finally90:
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (filename);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 640 "unattended-setup-box.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (filename);
#line 644 "unattended-setup-box.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return self ? g_object_ref (self) : NULL;
#line 651 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_setup_express_toggle (BoxesUnattendedSetupBox* self, gboolean live, gboolean needs_internet) {
	gboolean _tmp10_ = FALSE;
	GNetworkMonitor* network_monitor = NULL;
	GNetworkMonitor* _tmp11_ = NULL;
	GNetworkMonitor* _tmp12_ = NULL;
	GNetworkMonitor* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	GNetworkMonitor* _tmp15_ = NULL;
	GError * _inner_error_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 666 "unattended-setup-box.c"
	{
		gboolean _tmp0_ = FALSE;
		GKeyFile* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		GtkSwitch* _tmp4_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp1_ = self->priv->keyfile;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->media_path;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = g_key_file_get_boolean (_tmp1_, _tmp2_, BOXES_UNATTENDED_SETUP_BOX_EXPRESS_KEY, &_inner_error_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp3_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 683 "unattended-setup-box.c"
			goto __catch91_g_error;
		}
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = self->priv->express_toggle;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_switch_set_active (_tmp4_, _tmp0_);
#line 690 "unattended-setup-box.c"
	}
	goto __finally91;
	__catch91_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GtkSwitch* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = self->priv->media_path;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp6_ = _error_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp7_ = _tmp6_->message;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:161: Failed to read key '%s' under '%s': %s\n", BOXES_UNATTENDED_SETUP_BOX_EXPRESS_KEY, _tmp5_, _tmp7_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp8_ = self->priv->express_toggle;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp9_ = live;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_switch_set_active (_tmp8_, !_tmp9_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 721 "unattended-setup-box.c"
	}
	__finally91:
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 732 "unattended-setup-box.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp10_ = needs_internet;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (!_tmp10_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 740 "unattended-setup-box.c"
	}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp11_ = g_network_monitor_get_default ();
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	network_monitor = _tmp12_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp13_ = network_monitor;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp14_ = g_network_monitor_get_network_available (_tmp13_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_update_express_toggle (self, _tmp14_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp15_ = network_monitor;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_connect_object (_tmp15_, "network-changed", (GCallback) _boxes_unattended_setup_box_update_express_toggle_g_network_monitor_network_changed, self, 0);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (network_monitor);
#line 760 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_update_express_toggle (BoxesUnattendedSetupBox* self, gboolean network_available) {
	gboolean _tmp0_ = FALSE;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = network_available;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp0_) {
#line 772 "unattended-setup-box.c"
		GtkSwitch* _tmp1_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp1_ = self->priv->express_toggle;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, TRUE);
#line 778 "unattended-setup-box.c"
	} else {
		GtkSwitch* _tmp2_ = NULL;
		GtkSwitch* _tmp3_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->express_toggle;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = self->priv->express_toggle;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_switch_set_active (_tmp3_, FALSE);
#line 790 "unattended-setup-box.c"
	}
}


static void boxes_unattended_setup_box_set_entry_text_from_key (BoxesUnattendedSetupBox* self, GtkEntry* entry, const gchar* key, const gchar* default_value) {
	gchar* str = NULL;
	gboolean _tmp10_ = FALSE;
	const gchar* _tmp11_ = NULL;
	GError * _inner_error_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (entry != NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (key != NULL);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	str = NULL;
#line 808 "unattended-setup-box.c"
	{
		gchar* _tmp0_ = NULL;
		GKeyFile* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp1_ = self->priv->keyfile;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->media_path;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = key;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = g_key_file_get_string (_tmp1_, _tmp2_, _tmp3_, &_inner_error_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp4_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 828 "unattended-setup-box.c"
			goto __catch92_g_error;
		}
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = _tmp0_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (str);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		str = _tmp5_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (_tmp0_);
#line 841 "unattended-setup-box.c"
	}
	goto __finally92;
	__catch92_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp6_ = key;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp7_ = self->priv->media_path;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp8_ = _error_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp9_ = _tmp8_->message;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:187: Failed to read key '%s' under '%s': %s\n", _tmp6_, _tmp7_, _tmp9_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 867 "unattended-setup-box.c"
	}
	__finally92:
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (str);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 880 "unattended-setup-box.c"
	}
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp11_ = str;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp11_ != NULL) {
#line 886 "unattended-setup-box.c"
		const gchar* _tmp12_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp12_ = str;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp10_ = g_strcmp0 (_tmp12_, "") != 0;
#line 892 "unattended-setup-box.c"
	} else {
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp10_ = FALSE;
#line 896 "unattended-setup-box.c"
	}
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp10_) {
#line 900 "unattended-setup-box.c"
		GtkEntry* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp13_ = entry;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp14_ = str;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_entry_set_text (_tmp13_, _tmp14_);
#line 909 "unattended-setup-box.c"
	} else {
		const gchar* _tmp15_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp15_ = default_value;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp15_ != NULL) {
#line 916 "unattended-setup-box.c"
			GtkEntry* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp16_ = entry;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp17_ = default_value;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_entry_set_text (_tmp16_, _tmp17_);
#line 925 "unattended-setup-box.c"
		}
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (str);
#line 930 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_mandatory_input_changed (BoxesUnattendedSetupBox* self) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject*) self, "ready-to-create");
#line 939 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_mandatory_input_changed ((BoxesUnattendedSetupBox*) self);
#line 946 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_username_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 963 "unattended-setup-box.c"
	} else {
		gboolean _tmp2_ = FALSE;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = boxes_unattended_setup_box_get_username (self);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (g_strcmp0 (_tmp4_, "") != 0) {
#line 974 "unattended-setup-box.c"
			const gchar* _tmp5_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_format;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp2_ = _tmp5_ != NULL;
#line 980 "unattended-setup-box.c"
		} else {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp2_ = FALSE;
#line 984 "unattended-setup-box.c"
		}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp2_) {
#line 988 "unattended-setup-box.c"
			GtkEntry* _tmp6_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp6_ = self->priv->product_key_entry;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 994 "unattended-setup-box.c"
		}
	}
}


static void _boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_username_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 1003 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_password_button_clicked (BoxesUnattendedSetupBox* self) {
	GtkNotebook* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_notebook;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_notebook_next_page (_tmp0_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->password_entry;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 1020 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_password_button_clicked ((BoxesUnattendedSetupBox*) self);
#line 1027 "unattended-setup-box.c"
}


static gboolean boxes_unattended_setup_box_on_password_entry_focus_out (BoxesUnattendedSetupBox* self) {
	gboolean result = FALSE;
	GtkEntry* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	guint _tmp2_ = 0U;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text_length (_tmp0_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp2_ == ((guint) 0)) {
#line 1046 "unattended-setup-box.c"
		GtkNotebook* _tmp3_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = self->priv->password_notebook;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_notebook_prev_page (_tmp3_);
#line 1052 "unattended-setup-box.c"
	}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = FALSE;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1058 "unattended-setup-box.c"
}


static gboolean _boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = boxes_unattended_setup_box_on_password_entry_focus_out ((BoxesUnattendedSetupBox*) self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1067 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_password_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 1084 "unattended-setup-box.c"
	} else {
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = boxes_unattended_setup_box_get_username (self);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = _tmp2_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (g_strcmp0 (_tmp3_, "") == 0) {
#line 1094 "unattended-setup-box.c"
			GtkEntry* _tmp4_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp4_ = self->priv->username_entry;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp4_);
#line 1100 "unattended-setup-box.c"
		} else {
			const gchar* _tmp5_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_format;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			if (_tmp5_ != NULL) {
#line 1107 "unattended-setup-box.c"
				GtkEntry* _tmp6_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = self->priv->product_key_entry;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 1113 "unattended-setup-box.c"
			}
		}
	}
}


static void _boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_password_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 1123 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_key_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 1140 "unattended-setup-box.c"
	} else {
		GtkEntry* _tmp2_ = NULL;
		guint _tmp3_ = 0U;
		guint _tmp4_ = 0U;
		const gchar* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->product_key_entry;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = gtk_entry_get_text_length (_tmp2_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = self->priv->product_key_format;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp6_ = strlen (_tmp5_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp7_ = _tmp6_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp4_ == ((guint) _tmp7_)) {
#line 1162 "unattended-setup-box.c"
			GtkEntry* _tmp8_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp8_ = self->priv->username_entry;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 1168 "unattended-setup-box.c"
		}
	}
}


static void _boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_key_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 1177 "unattended-setup-box.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 1086 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1195 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_key_text_inserted (BoxesUnattendedSetupBox* self, const gchar* text, gint text_length, gint* position) {
	gboolean _tmp0_ = FALSE;
	gchar* _result_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp40_ = NULL;
	GtkEntry* _tmp48_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (text != NULL);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->we_inserted_text;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp0_) {
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 1215 "unattended-setup-box.c"
	}
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = g_strdup ("");
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_result_ = _tmp1_;
#line 1221 "unattended-setup-box.c"
	{
		guint i = 0U;
		guint j = 0U;
		gint _tmp2_ = 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		i = (guint) 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = *position;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		j = (guint) _tmp2_;
#line 1232 "unattended-setup-box.c"
		{
			gboolean _tmp3_ = FALSE;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = TRUE;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			while (TRUE) {
#line 1239 "unattended-setup-box.c"
				gboolean _tmp4_ = FALSE;
				guint _tmp5_ = 0U;
				gint _tmp6_ = 0;
				gchar character = '\0';
				const gchar* _tmp11_ = NULL;
				guint _tmp12_ = 0U;
				gchar _tmp13_ = '\0';
				gchar allowed_char = '\0';
				const gchar* _tmp14_ = NULL;
				guint _tmp15_ = 0U;
				gchar _tmp16_ = '\0';
				gboolean skip_input_char = FALSE;
				gchar _tmp17_ = '\0';
				guint _tmp32_ = 0U;
				gboolean _tmp33_ = FALSE;
				const gchar* _tmp34_ = NULL;
				gchar _tmp35_ = '\0';
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				guint _tmp39_ = 0U;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (!_tmp3_) {
#line 1263 "unattended-setup-box.c"
				}
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp3_ = FALSE;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp5_ = i;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = text_length;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp5_ < ((guint) _tmp6_)) {
#line 1273 "unattended-setup-box.c"
					guint _tmp7_ = 0U;
					const gchar* _tmp8_ = NULL;
					gint _tmp9_ = 0;
					gint _tmp10_ = 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp7_ = j;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp8_ = self->priv->product_key_format;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp9_ = strlen (_tmp8_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp10_ = _tmp9_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp4_ = _tmp7_ < ((guint) _tmp10_);
#line 1288 "unattended-setup-box.c"
				} else {
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp4_ = FALSE;
#line 1292 "unattended-setup-box.c"
				}
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (!_tmp4_) {
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					break;
#line 1298 "unattended-setup-box.c"
				}
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp11_ = text;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp12_ = i;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp13_ = string_get (_tmp11_, (glong) _tmp12_);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				character = _tmp13_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp14_ = self->priv->product_key_format;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp15_ = j;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp16_ = string_get (_tmp14_, (glong) _tmp15_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				allowed_char = _tmp16_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				skip_input_char = FALSE;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp17_ = allowed_char;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				switch (_tmp17_) {
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '@':
#line 1324 "unattended-setup-box.c"
					{
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1328 "unattended-setup-box.c"
					}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '%':
#line 1332 "unattended-setup-box.c"
					{
						gchar _tmp18_ = '\0';
						gboolean _tmp19_ = FALSE;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp18_ = character;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp19_ = g_ascii_isalpha (_tmp18_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp19_) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 1344 "unattended-setup-box.c"
						}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1348 "unattended-setup-box.c"
					}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '#':
#line 1352 "unattended-setup-box.c"
					{
						gchar _tmp20_ = '\0';
						gboolean _tmp21_ = FALSE;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp20_ = character;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp21_ = g_ascii_isdigit (_tmp20_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp21_) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 1364 "unattended-setup-box.c"
						}
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1368 "unattended-setup-box.c"
					}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '$':
#line 1372 "unattended-setup-box.c"
					{
						gchar _tmp22_ = '\0';
						gboolean _tmp23_ = FALSE;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp22_ = character;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp23_ = g_ascii_isalnum (_tmp22_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp23_) {
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 1384 "unattended-setup-box.c"
						}
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1388 "unattended-setup-box.c"
					}
					default:
					{
						gchar _tmp24_ = '\0';
						gchar _tmp25_ = '\0';
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp24_ = character;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp25_ = allowed_char;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (_tmp24_ != _tmp25_) {
#line 1400 "unattended-setup-box.c"
							const gchar* _tmp26_ = NULL;
							gchar _tmp27_ = '\0';
							gchar* _tmp28_ = NULL;
							gchar* _tmp29_ = NULL;
							gchar* _tmp30_ = NULL;
							guint _tmp31_ = 0U;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp26_ = _result_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp27_ = allowed_char;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp28_ = g_strdup_printf ("%c", _tmp27_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp29_ = _tmp28_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp30_ = g_strconcat (_tmp26_, _tmp29_, NULL);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_g_free0 (_result_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_result_ = _tmp30_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_g_free0 (_tmp29_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp31_ = j;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							j = _tmp31_ + 1;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							continue;
#line 1429 "unattended-setup-box.c"
						}
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1433 "unattended-setup-box.c"
					}
				}
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp32_ = i;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				i = _tmp32_ + 1;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp33_ = skip_input_char;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp33_) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					continue;
#line 1446 "unattended-setup-box.c"
				}
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp34_ = _result_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp35_ = character;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp36_ = g_strdup_printf ("%c", _tmp35_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp37_ = _tmp36_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp38_ = g_strconcat (_tmp34_, _tmp37_, NULL);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_g_free0 (_result_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_result_ = _tmp38_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_g_free0 (_tmp37_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp39_ = j;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				j = _tmp39_ + 1;
#line 1468 "unattended-setup-box.c"
			}
		}
	}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp40_ = _result_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (g_strcmp0 (_tmp40_, "") != 0) {
#line 1476 "unattended-setup-box.c"
		GtkEntry* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
		gint _tmp46_ = 0;
		gint _tmp47_ = 0;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		self->priv->we_inserted_text = TRUE;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp41_ = self->priv->product_key_entry;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp42_ = _result_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp43_ = g_utf8_strup (_tmp42_, (gssize) -1);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp44_ = _tmp43_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp45_ = _result_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp46_ = strlen (_tmp45_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp47_ = _tmp46_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_editable_insert_text ((GtkEditable*) _tmp41_, _tmp44_, _tmp47_, position);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (_tmp44_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		self->priv->we_inserted_text = FALSE;
#line 1506 "unattended-setup-box.c"
	}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp48_ = self->priv->product_key_entry;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_stop_emission_by_name (_tmp48_, "insert-text");
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (_result_);
#line 1514 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_key_text_inserted ((BoxesUnattendedSetupBox*) self, new_text, new_text_length, position);
#line 1521 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_ready_for_express (BoxesUnattendedSetupBox* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = boxes_unattended_setup_box_get_username (self);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (g_strcmp0 (_tmp2_, "") != 0) {
#line 1538 "unattended-setup-box.c"
		gboolean _tmp3_ = FALSE;
		const gchar* _tmp4_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = self->priv->product_key_format;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp4_ == NULL) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = TRUE;
#line 1547 "unattended-setup-box.c"
		} else {
			GtkEntry* _tmp5_ = NULL;
			guint _tmp6_ = 0U;
			guint _tmp7_ = 0U;
			const gchar* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gint _tmp10_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_entry;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp6_ = gtk_entry_get_text_length (_tmp5_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp7_ = _tmp6_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp8_ = self->priv->product_key_format;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp9_ = strlen (_tmp8_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp10_ = _tmp9_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = _tmp7_ == ((guint) _tmp10_);
#line 1569 "unattended-setup-box.c"
		}
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp3_;
#line 1573 "unattended-setup-box.c"
	} else {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = FALSE;
#line 1577 "unattended-setup-box.c"
	}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1583 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_ready_to_create (BoxesUnattendedSetupBox* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	GtkSwitch* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->express_toggle;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = gtk_switch_get_active (_tmp1_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = _tmp2_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (!_tmp3_) {
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = TRUE;
#line 1605 "unattended-setup-box.c"
	} else {
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = _tmp4_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp5_;
#line 1615 "unattended-setup-box.c"
	}
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp0_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1621 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self) {
	gboolean result;
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->express_toggle;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp2_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1642 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_set_express_install (BoxesUnattendedSetupBox* self, gboolean value) {
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->express_toggle;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = value;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_switch_set_active (_tmp0_, _tmp1_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject *) self, "express-install");
#line 1659 "unattended-setup-box.c"
}


const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self) {
	const gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->username_entry;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp2_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1680 "unattended-setup-box.c"
}


gchar* boxes_unattended_setup_box_get_password (BoxesUnattendedSetupBox* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp3_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1704 "unattended-setup-box.c"
}


static gchar* g_unichar_to_string (gunichar self) {
	gchar* result = NULL;
	gchar* str = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 941 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 7);
#line 941 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	str = (gchar*) _tmp0_;
#line 942 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = str;
#line 942 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_unichar_to_utf8 (self, _tmp1_);
#line 943 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = str;
#line 943 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1725 "unattended-setup-box.c"
}


gchar* boxes_unattended_setup_box_get_hidden_password (BoxesUnattendedSetupBox* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = strlen (_tmp2_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp4_ = _tmp3_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp4_ > 0) {
#line 1750 "unattended-setup-box.c"
		gchar* str = NULL;
		gchar* _tmp5_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = g_strdup ("");
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		str = _tmp5_;
#line 1757 "unattended-setup-box.c"
		{
			gint i = 0;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			i = 0;
#line 1762 "unattended-setup-box.c"
			{
				gboolean _tmp6_ = FALSE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = TRUE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				while (TRUE) {
#line 1769 "unattended-setup-box.c"
					gint _tmp8_ = 0;
					GtkEntry* _tmp9_ = NULL;
					guint _tmp10_ = 0U;
					guint _tmp11_ = 0U;
					const gchar* _tmp12_ = NULL;
					GtkEntry* _tmp13_ = NULL;
					gunichar _tmp14_ = 0U;
					gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					gchar* _tmp17_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					if (!_tmp6_) {
#line 1782 "unattended-setup-box.c"
						gint _tmp7_ = 0;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp7_ = i;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						i = _tmp7_ + 1;
#line 1788 "unattended-setup-box.c"
					}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp6_ = FALSE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp8_ = i;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp9_ = self->priv->password_entry;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp10_ = gtk_entry_get_text_length (_tmp9_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp11_ = _tmp10_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					if (!(((guint) _tmp8_) < _tmp11_)) {
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1804 "unattended-setup-box.c"
					}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp12_ = str;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp13_ = self->priv->password_entry;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp14_ = gtk_entry_get_invisible_char (_tmp13_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp15_ = g_unichar_to_string (_tmp14_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp16_ = _tmp15_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp17_ = g_strconcat (_tmp12_, _tmp16_, NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_g_free0 (str);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					str = _tmp17_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_g_free0 (_tmp16_);
#line 1824 "unattended-setup-box.c"
				}
			}
		}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		result = str;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return result;
#line 1832 "unattended-setup-box.c"
	} else {
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp18_ = _ ("no password");
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp19_ = g_strdup (_tmp18_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		result = _tmp19_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return result;
#line 1844 "unattended-setup-box.c"
	}
}


gchar* boxes_unattended_setup_box_get_product_key (BoxesUnattendedSetupBox* self) {
	gchar* result;
	const gchar* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	gchar* _tmp5_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->product_key_entry;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_ != NULL) {
#line 1860 "unattended-setup-box.c"
		GtkEntry* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->product_key_entry;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp4_;
#line 1872 "unattended-setup-box.c"
	} else {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = NULL;
#line 1876 "unattended-setup-box.c"
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp5_ = g_strdup (_tmp0_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp5_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1884 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_set_avatar_path (BoxesUnattendedSetupBox* self, const gchar* value) {
	GError * _inner_error_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 1892 "unattended-setup-box.c"
	{
		GdkPixbuf* pixbuf = NULL;
		const gchar* _tmp0_ = NULL;
		GdkPixbuf* _tmp1_ = NULL;
		GtkImage* _tmp2_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = value;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp1_ = gdk_pixbuf_new_from_file_at_scale (_tmp0_, 64, 64, TRUE, &_inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		pixbuf = _tmp1_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1906 "unattended-setup-box.c"
			goto __catch93_g_error;
		}
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->user_avatar;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_object_set (_tmp2_, "pixbuf", pixbuf, NULL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_object_unref0 (pixbuf);
#line 1915 "unattended-setup-box.c"
	}
	goto __finally93;
	__catch93_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = value;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _error_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = _tmp4_->message;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:68: Failed to load user avatar file '%s': %s", _tmp3_, _tmp5_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 1938 "unattended-setup-box.c"
	}
	__finally93:
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 1949 "unattended-setup-box.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject *) self, "avatar-path");
#line 1953 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_class_init (BoxesUnattendedSetupBoxClass * klass) {
	gint BoxesUnattendedSetupBox_private_offset;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedSetupBoxPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_setup_box_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_unattended_setup_box_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_setup_box_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS, g_param_spec_boolean ("ready-for-express", "ready-for-express", "ready-for-express", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE, g_param_spec_boolean ("ready-to-create", "ready-to-create", "ready-to-create", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL, g_param_spec_boolean ("express-install", "express-install", "express-install", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_USERNAME, g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_PASSWORD, g_param_spec_string ("password", "password", "password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD, g_param_spec_string ("hidden-password", "hidden-password", "hidden-password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY, g_param_spec_string ("product-key", "product-key", "product-key", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH, g_param_spec_string ("avatar-path", "avatar-path", "avatar-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	BoxesUnattendedSetupBox_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/unattended-setup-box.ui");
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_new ("user_wants_to_create", BOXES_TYPE_UNATTENDED_SETUP_BOX, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "needs_internet_bar", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, needs_internet_bar));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "needs_internet_label", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, needs_internet_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_grid", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, setup_grid));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "express_label", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, express_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "express_toggle", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, express_toggle));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "user_avatar", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, user_avatar));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "username_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, username_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "password_notebook", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, password_notebook));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "password_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, password_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "product_key_label", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, product_key_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "product_key_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, product_key_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_mandatory_input_changed", G_CALLBACK(_boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_username_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_button_clicked", G_CALLBACK(_boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_entry_focus_out", G_CALLBACK(_boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_text_inserted", G_CALLBACK(_boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text));
#line 2027 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_instance_init (BoxesUnattendedSetupBox * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv = BOXES_UNATTENDED_SETUP_BOX_GET_PRIVATE (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 2036 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_finalize (GObject* obj) {
	BoxesUnattendedSetupBox * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->needs_internet_bar);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->needs_internet_label);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->setup_grid);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->express_label);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->express_toggle);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->user_avatar);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->password_notebook);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->product_key_label);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->product_key_entry);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->product_key_format);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->media_path);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_key_file_unref0 (self->priv->keyfile);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (boxes_unattended_setup_box_parent_class)->finalize (obj);
#line 2074 "unattended-setup-box.c"
}


GType boxes_unattended_setup_box_get_type (void) {
	static volatile gsize boxes_unattended_setup_box_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_setup_box_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedSetupBoxClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_setup_box_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedSetupBox), 0, (GInstanceInitFunc) boxes_unattended_setup_box_instance_init, NULL };
		GType boxes_unattended_setup_box_type_id;
		boxes_unattended_setup_box_type_id = g_type_register_static (gtk_box_get_type (), "BoxesUnattendedSetupBox", &g_define_type_info, 0);
		g_once_init_leave (&boxes_unattended_setup_box_type_id__volatile, boxes_unattended_setup_box_type_id);
	}
	return boxes_unattended_setup_box_type_id__volatile;
}


static void _vala_boxes_unattended_setup_box_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedSetupBox * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_ready_for_express (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_ready_to_create (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_express_install (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_string (value, boxes_unattended_setup_box_get_username (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_hidden_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_product_key (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 2137 "unattended-setup-box.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 2143 "unattended-setup-box.c"
	}
}


static void _vala_boxes_unattended_setup_box_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesUnattendedSetupBox * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_express_install (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_avatar_path (self, g_value_get_string (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 2165 "unattended-setup-box.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 2171 "unattended-setup-box.c"
	}
}



